summaryrefslogtreecommitdiff
path: root/js/Article.js
diff options
context:
space:
mode:
Diffstat (limited to 'js/Article.js')
-rw-r--r--js/Article.js7
1 files changed, 2 insertions, 5 deletions
diff --git a/js/Article.js b/js/Article.js
index 538377f45..d6e7bbad9 100644
--- a/js/Article.js
+++ b/js/Article.js
@@ -1,6 +1,6 @@
'use strict'
/* global __, ngettext, App, Headlines, xhrPost, xhrJson, dojo, dijit, PluginHost, Notify, $$, Ajax */
const Article = {
_scroll_reset_timeout: false,
@@ -250,12 +250,9 @@ const Article = {
return false;
},
editTags: function (id) {
- if (dijit.byId("editTagsDlg"))
- dijit.byId("editTagsDlg").destroyRecursive();
-
xhrPost("backend.php", {op: "article", method: "editarticletags", param: id}, (transport) => {
- const dialog = new dijit.Dialog({
+ const dialog = new fox.SingleUseDialog({
id: "editTagsDlg",
title: __("Edit article Tags"),
content: transport.responseText,
@@ -1,6 +1,6 @@
'use strict'
-/* global __, ngettext, App, Headlines, xhrPost, xhrJson, dojo, dijit, PluginHost, Notify, $$, Ajax */
+/* global __, ngettext, App, Headlines, xhrPost, xhrJson, dojo, dijit, PluginHost, Notify, $$, Ajax, fox */
const Article = {
_scroll_reset_timeout: false,